import { Link as RLink } from 'react-router-dom'
import { useTranslation } from 'react-i18next'
import { styled } from '@mui/material/styles'
import { Box, Link } from '@mui/material'
import LogoutIcon from '@mui/icons-material/Logout'

import { useUserContext } from 'contexts'

import LanguageSelector from 'components/languageselector'
import UserInfo from 'routes/components/userInfo'
import { getHeaderLogo } from './logos'

const StyledHeader = styled('header')(({ theme }) => ({
  color: theme.greg.h1TextColor,
  backgroundColor: theme.greg.headerBackgroundColor,

  a: {
    textDecoration: 'none',

    '&:hover, &:focus': {
      textDecoration: 'underline',
    },
  },
}))

const MainContainer = styled('div')(({ theme }) => ({
  display: 'flex',
  justifyContent: 'space-between',
  margin: '0 auto',
  maxWidth: theme.greg.appMaxWidth,
  padding: '1rem 6.5rem 1rem 6.5rem',
  alignItems: 'flex-end',
}))

const LogoContainer = styled('div')({
  display: 'flex',
  flexDirection: 'row',
  alignItems: 'flex-end',
  // paddingRight: '2rem',
})

const Menu = styled('div')({
  display: 'flex',
  // listStyleType: 'none',
  flexDirection: 'row',
  alignItems: 'flex-end',
  fontSize: '1rem',
  paddingBottom: '0.5rem',
})

const Header = () => {
  const { t } = useTranslation('common')
  const { user } = useUserContext()

  return (
    <StyledHeader>
      <MainContainer>
        <LogoContainer>
          <Box
            sx={{
              paddingRight: '1.5rem',
              width: '7rem',
              // minWidth: '10rem',
            }}
          >
            {getHeaderLogo()}
          </Box>
          <RLink to="/">
            <Box
              sx={{
                color: 'white',
                whiteSpace: 'nowrap',
                textDecoration: 'none',
                fontSize: '2rem',
                fontWeight: 'bold',
              }}
            >
              {t('header.applicationTitle')}
            </Box>
          </RLink>
        </LogoContainer>
        <Menu>
          <LanguageSelector noPadding />
          <UserInfo />
          {user.auth && (
            <Box sx={{ paddingLeft: '1rem' }}>
              <Link
                sx={{
                  color: 'white',
                }}
                href="/oidc/logout"
              >
                Logg ut
                <LogoutIcon
                  fontSize="small"
                  sx={{
                    paddingLeft: '0.3rem',
                    verticalAlign: 'middle',
                  }}
                />
              </Link>
            </Box>
          )}
        </Menu>
      </MainContainer>
    </StyledHeader>
  )
}

export default Header
